# config.tcl  -  96/07/19
##############################################################################
# GFax version 1.0
#
#   Copyright (c) 1996  George A. Farris,
#                       G.M. Systems,
#                       2570 Seaview Road,
#                       Mill Bay, British Columbia,
#                       Canada  V0R 2P0
#
#                       E-Mail: george@gmsys.com
#
#   All rights reserved.
#
#  Redistribution and use for non-commercial purposes in source and 
#  binary forms are permitted provided that the above copyright 
#  notice and this document are duplicated in all such forms and that 
#  any documentation, advertising materials, and other materials 
#  related to such distribution and use acknowledge that the software 
#  was developed by George A. Farris. 
#
#  This is SHAREWARE. As you will see from the following paragraphs,
#  I am trying to keep this as simple as possible while still
#  trying to get some benefit for myself from this software. 
#  It is an awful lot of work writing and maintaining such a package,
#  so please take the time to read this and comply to it.
#
#  Private use of GFax:
#
#  You are granted the right to use GFax for private purpose free
#  of charge.
#  
#  Using GFax in a commercial environment:        (very cheap!)
#  
#  A license for using GFax in a commercial or educational environment
#  can be obtained from the author for a small fee. To register your
#  copy of GFax, contact the author at the address above or just 
#  send an email. Registration fees for a "small" environment start
#  from US $10 and are negotiable. This will enable you to receive
#  full support and information on GFax development from the author.    
#
#  Distributions:
#
#  I would like to make GFax accessible to as many people as possible.
#  Therefor I grant the permission to include GFax in any Linux
#  distributions, as long as it is only a minor part of the distribution.
#  I would appreciate a copy of the distribution be sent to me for
#  support purposes but it isn't necessary.  You are not allowed to sell
#  or distribute any software package which is based mainly or derived from
#  GFax withour prior written permission from the author.
#  
#  If you are in doubt whether you can distribute GFax or not, just
#  contact the author. Including it in a distribution which is also
#  available free of charge (e.g. by FTP), is fine. 
#
#
#  NO WARRANTY:
#  
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
#  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-
#  INFRINGEMENT.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
#  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
#  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECT-
#  ION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
##############################################################################

# Read or Set configuration options
proc config {run_or_set} {
	global cover_page
	global send_now
	global network_fax
	global send_mail
	global resolution

	global fax_host 
	global net_port 
	global user_name
	global user_email 
	global fax_number
	global prefix 
	global covpage_file 
	global spool_dir

	global fax_software
	
	global send_bg_color
	global send_fg_color
	global gfax_home
	global home

		
	if { $run_or_set == "set" } {
		toplevel .cfg
		wm title .cfg "Configure GFax" 

		set f ".cfg"
		
		# Set up check and radio buttons
		frame .cfg.b
		pack .cfg.b -side top -fill x
		
		set fcb $f.b.cb
		set frb $f.b.rb
		
		frame $fcb -relief ridge -borderwidth 3 -bg $send_bg_color
		frame $frb -relief ridge -borderwidth 3 -bg $send_bg_color
		pack $fcb -side left -padx 10 -pady 5 -fill y
		pack $frb -side right -padx 10 -pady 5 -fill y

		checkbutton $fcb.coverpg -text "Send cover page" \
			-variable cover_page -bg $send_bg_color -anchor w
		checkbutton $fcb.sendnow -text "Send immediately" \
			-variable send_now -bg $send_bg_color -anchor w
		checkbutton $fcb.netfax -text "Network fax server" \
			-variable network_fax -bg $send_bg_color -anchor w
		checkbutton $fcb.sendmail -text "Send mail when complete" \
			-variable send_mail -bg $send_bg_color -anchor w
		checkbutton $fcb.resolution -text "High resolution, 198 lpi" \
			-variable resolution -bg $send_bg_color -anchor w

		pack $fcb.coverpg -side top -padx 2 -fill x
		pack $fcb.sendnow -side top -padx 2 -fill x
		pack $fcb.netfax -side top -padx 2 -fill x
		pack $fcb.sendmail -side top -padx 2 -fill x
		pack $fcb.resolution -side top -padx 2 -fill x

		label $frb.label -text "System Fax Software\n" -bg $send_bg_color
		radiobutton $frb.sfax -text "Mgetty+Sendfax" -anchor w\
			-variable fax_software -value sfax -bg $send_bg_color
		radiobutton $frb.efax -text "Efax" -anchor w -state disabled\
			-variable fax_software -value efax -bg $send_bg_color
		radiobutton $frb.hfax -text "Hylafax" -anchor w -state disabled\
			-variable fax_software -value hfax -bg $send_bg_color

		pack $frb.label -side top
		pack $frb.sfax -side top -padx 2 -fill x
		pack $frb.efax -side top -padx 2 -fill x
		pack $frb.hfax -side top -padx 2 -fill x
		

		# Set up entry boxes
		frame .cfg.e -relief ridge -borderwidth 3 -bg $send_bg_color
		pack .cfg.e -side top -padx 10 

		foreach el {fax_host net_port user_name user_email fax_number \
					prefix covpage_file spool_dir} {
			set state normal			
			switch $el {
				fax_host		{set l "Fax Host: "}
				net_port		{set l "TCP Port: "}
				user_name		{set l "User Name: "}
				user_email		{set l "Email Address: "}
				fax_number		{set l "Facsimile Number: "}
				prefix			{set l "Telephone Prefix: "}
				covpage_file	{set l "Cover Page File / Program: "}
				spool_dir		{set l "GFax Spool Directory: "}
			}
	
			set fe $f.e.$el
			frame $fe -bg $send_bg_color
			pack $fe -side top -fill x -padx 5
	
			label $fe.label \
				-text $l \
				-relief flat -anchor e \
				-bg $send_bg_color -fg $send_fg_color
			entry $fe.entry  -textvariable $el \
				-relief sunken -borderwidth 2 -width 30\
				-bg white -fg $send_fg_color
	
			pack $fe.entry -side right -pady 3
			pack $fe.label -side right -pady 3

		}
	
		frame $f.fd3 -height 4m
		pack $f.fd3 -side top
	
		button $f.cancel -text "Cancel" -width 10 -command {destroy .cfg}
		pack $f.cancel -side left -padx 3 -pady 3

		button $f.ok -text "Ok" -width 10 -command "SaveDefaults"
		pack $f.ok -side right -padx 3 -pady 3

# Else get running defaults from config file
	} else {
		
		# If a HOME/.gfax/gfaxrc file exists use it
		if { [file readable $home/.gfax/gfaxrc] } {
			set fd [open $home/.gfax/gfaxrc]
		} elseif {[file readable $gfax_home/gfaxrc]} {
			set fd [open $gfax_home/gfaxrc] 
		} else {
			config set
			exit
		}		
		
		gets $fd line

		if { [string trim $line] != "\[checkbuttons\]" } {
			puts "Error in rc file"
			exit
		}
			
		while { [string trim $line] != "\[radiobuttons\]" } {
			gets $fd line
			switch [lindex $line 0] {
				cover_page	{set cover_page [lindex $line 1]}
				send_now	{set send_now [lindex $line 1]}
				network_fax	{set network_fax [lindex $line 1]}
				send_mail	{set send_mail [lindex $line 1]}
				resolution	{set resolution [lindex $line 1]}
			}
		}

		while { [string trim $line] != "\[entries\]" } {
			gets $fd line
			if { [lindex $line 2] == "Y" } {
				switch [lindex $line 1] {
					sfax	{set fax_software sfax}
					efax	{set fax_software efax}
					hfax	{set fax_software hfax}
				}
			}
		}
		
		while { ![eof $fd] } {
			gets $fd line
			switch [lindex $line 0] {
				fax_host		{set fax_host [lindex $line 1]}
				net_port		{set net_port [lindex $line 1]}
				user_name		{set user_name [lrange $line 1 2]}
				user_email		{set user_email [lindex $line 1]}
				fax_number		{set fax_number [lindex $line 1]}
				prefix			{set prefix [lindex $line 1]}
				covpage_file	{set covpage_file [lindex $line 1]}
				spool_dir		{set spool_dir [lindex $line 1]}
			}
		}
		close $fd
	}
}
