# phbook.tcl  -  96/07/19
##############################################################################
# GFax version 1.0
#
#   Copyright (c) 1996  George A. Farris,
#                       G.M. Systems,
#                       2570 Seaview Road,
#                       Mill Bay, British Columbia,
#                       Canada  V0R 2P0
#
#                       E-Mail: george@gmsys.com
#
#   All rights reserved.
#
#  Redistribution and use for non-commercial purposes in source and 
#  binary forms are permitted provided that the above copyright 
#  notice and this document are duplicated in all such forms and that 
#  any documentation, advertising materials, and other materials 
#  related to such distribution and use acknowledge that the software 
#  was developed by George A. Farris. 
#
#  This is SHAREWARE. As you will see from the following paragraphs,
#  I am trying to keep this as simple as possible while still
#  trying to get some benefit for myself from this software. 
#  It is an awful lot of work writing and maintaining such a package,
#  so please take the time to read this and comply to it.
#
#  Private use of GFax:
#
#  You are granted the right to use GFax for private purpose free
#  of charge.
#  
#  Using GFax in a commercial environment:        (very cheap!)
#  
#  A license for using GFax in a commercial or educational environment
#  can be obtained from the author for a small fee. To register your
#  copy of GFax, contact the author at the address above or just 
#  send an email. Registration fees for a "small" environment start
#  from US $10 and are negotiable. This will enable you to receive
#  full support and information on GFax development from the author.    
#
#  Distributions:
#
#  I would like to make GFax accessible to as many people as possible.
#  Therefor I grant the permission to include GFax in any Linux
#  distributions, as long as it is only a minor part of the distribution.
#  I would appreciate a copy of the distribution be sent to me for
#  support purposes but it isn't necessary.  You are not allowed to sell
#  or distribute any software package which is based mainly or derived from
#  GFax withour prior written permission from the author.
#  
#  If you are in doubt whether you can distribute GFax or not, just
#  contact the author. Including it in a distribution which is also
#  available free of charge (e.g. by FTP), is fine. 
#
#
#  NO WARRANTY:
#  
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
#  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-
#  INFRINGEMENT.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
#  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
#  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECT-
#  ION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
##############################################################################

# Phone book command {} {
proc PhoneBook {} {
	global phone
	global name
	global atten
	global prefix

	global send_bg_color
		
#	set alphabet {A B C D E F G H I J K L M N O P Q R S T U V W X Y Z}
	
	toplevel .pb
	wm title .pb "Phone Book"
	# Can't resize phone book
	wm resizable .pb 0 0
	
	# Put a row of labels across the top.
	frame .pb.ab
	pack .pb.ab -side top -fill x
	
	label .pb.ab.labeln -text "Name                              "
	label .pb.ab.labela -text "Attention                         "
	label .pb.ab.labelp -text "Phone                     "
	label .pb.ab.labelx -text "Prefix"

	pack .pb.ab.labeln -side left
	pack .pb.ab.labela -side left
	pack .pb.ab.labelp -side left
	pack .pb.ab.labelx -side left
	
#	foreach el $alphabet {
#		button .pb.ab.b$el -text $el -padx 0 -pady 0 -relief flat -command Show$el
#		pack .pb.ab.b$el -side left
#	}
	
	# Create a text widget to log the output
	frame .pb.t 
	pack .pb.t -side top

	listbox .pb.t.text -relief sunken -borderwidth 2 \
		-width 70 -height 15 -bg $send_bg_color\
		-font \
		-adobe-courier-medium-r-normal--12-*-*-*-*-*-iso8859-1\
		-yscrollcommand ".pb.t.scroll set" 

	scrollbar .pb.t.scroll -command {.pb.t.text yview}

	pack .pb.t.scroll -side right -fill y
	pack .pb.t.text -side left

	bind .pb.t.text <Double-Button-1> {
		set dest [selection get]

		set name [string range $dest 0 22]
		set atten [string range $dest 23 45]
		set phone [string range $dest 46 63]
		set prefix [string range $dest 64 end]
		destroy .pb
	}

	frame .pb.fd1 -height 4m -bg $send_bg_color
	pack .pb.fd1 -side top
	
	# make button frame
	frame .pb.but 
	pack .pb.but -side top -fill x

	button .pb.but.cancel -text "Cancel" -width 13 -command {destroy .pb}
	pack .pb.but.cancel -side left -fill x

	button .pb.but.new -text "Add New" -width 8 -command AddNew
	pack .pb.but.new -side left -fill x 

	button .pb.but.del -text "Delete" -width 8 -command Delete
	pack .pb.but.del -side left -fill x 

	button .pb.but.edit -text "Edit" -width 8 -command Edit
	pack .pb.but.edit -side left -fill x

	button .pb.but.ok -text "Ok" -width 13 -command {
		set x [catch {set dest [selection get]}]
		if { $x == 0} {
			set name [string range $dest 0 22]
			set atten [string range $dest 23 45]
			set phone [string range $dest 46 63]
			set prefix [string range $dest 64 end]
		} else {
			set name ""
			set atten ""
			set phone ""
			set prefix None
		}


		destroy .pb}
	pack .pb.but.ok -side right -fill x
		
	LoadFile
}

# function to load the listbox
proc LoadFile {} {
	global gfax_home home
	
	# Clear then load listbox	
	.pb.t.text delete 0 end

	# If a HOME/.gfax/phbook file exists use it
	if { [file readable $home/.gfax/phbook] } {
		set fd [open $home/.gfax/phbook a+]
	} else {
		set fd [open $gfax_home/phbook a+]
	}
	
	# Point to beginning of file
	seek $fd 0
	
	while {![eof $fd]} {
		gets $fd line
		
		set vars [split $line :]

		set name [lindex $vars 0]
		set atten [lindex $vars 1]
		set phone [lindex $vars 2]
		set prefix [lindex $vars 3]
	
		set fline [format "%s   %s   %s   %s" $name $atten $phone $prefix]

		.pb.t.text insert end $fline
	}
	
	close $fd
}

# Add new entry to the phone book.
proc AddNew {} {
	global name atten phone prefix
	
	AddEditPU Add	

	focus .op.phone.entry

	.op.phone.entry delete 0 end
	.op.name.entry delete 0 end
	.op.atten.entry delete 0 end
#	.op.prefix.entry delete 0 end
}


# Edit selected entry.
proc Edit {} {
	global name atten phone prefix key

	# Clear key
	set key ""
	set s [selection get]
	set name [string range $s 0 22]
	set atten [string range $s 23 45]
	set phone [string range $s 46 60]
	set prefix [string range $s 64 end]
	# Set a key for comparing entry to replace in adbook.db
	set key $phone

	AddEditPU Edit 
}

# Delete selected entry.
proc Delete {} {
	global name atten phone prefix key
	global gfax_home home
	
	# Clear key and book
	set key ""
	set adbook ""

	if {[popmsgYorN delpb Alert "\nReally delete\n" Delete]} {
	
		set s [selection get]

		# Set a key for comparing entry to replace in adbook.db
		set key [string range $s 46 60]

		# Read the phone book and loop doing command

		# If a HOME/.gfax/phbook file exists use it
		if { [file readable $home/.gfax/phbook] } {
			set fd [open $home/.gfax/phbook r]
		} else {
			set fd [open $gfax_home/phbook r]
		}

		while {![eof $fd]} {
			gets $fd line

			# Split out the variables
			set vars [split $line :]

			# If this is the deleted entry skip it.
			set s1 [lindex $vars 2]

			if {$s1 != $key} {
				lappend adbook $line
			}
		}
		close $fd

		# Lets sort it
		set sortedbook [lsort $adbook]
	
		# Reopen the file
		# If a HOME/.gfax/phbook file exists use it
		if { [file readable $home/.gfax/phbook] } {
			set fd [open $home/.gfax/phbook w]
		} else {
			set fd [open $gfax_home/phbook w]
		}

		# Now write the new file.
		foreach i $sortedbook {
			# This will omit any null entries
			if {$i > 1} {
				puts $fd $i
			}
		}
	
		flush $fd
		close $fd
		#destroy .op
	
		# Reload the listbox
		LoadFile
	}
}

# Add or edit popup box
proc AddEditPU {op} {
	global gfax_home
	global phone
	global name	
	global atten
	global prefix
	
	global send_bg_color
	global send_fg_color
	
	toplevel .op -bg $send_bg_color
	wm title .op "$op Entry" 

	set fsw ".op"

	foreach el {phone name atten prefix} {
		switch $el {
			phone	{set l "Fax Number: "}
			name	{set l "Name: "}
			atten	{set l "Attention: "}
			prefix	{set l "Prefix: "}
		}
	
		set fswe $fsw.$el
		frame $fswe -bg $send_bg_color
		pack $fswe -side top -fill x -padx 5
	
		label $fswe.label \
			-text $l \
			-relief flat -anchor e \
			-bg $send_bg_color -fg $send_fg_color
		entry $fswe.entry  -textvariable $el\
			-relief sunken -borderwidth 2\
			-bg white -fg $send_fg_color
	
		pack $fswe.entry -side right -pady 3
		pack $fswe.label -side right -pady 3
	}
	
	frame $fsw.fd3 -height 8m -bg $send_bg_color
	pack $fsw.fd3 -side top
	
	button $fsw.cancel -text "Cancel" -width 10 -command {destroy .op}
	pack $fsw.cancel -side left

	button $fsw.ok -text "Ok" -width 10 -command "finish $op"
	pack $fsw.ok -side right

	frame $fsw.fd4 -height 4m -bg $send_bg_color
	pack $fsw.fd4 -side top

}

# Finish with an Edit, Delete or Add command.
proc finish {command} {
	global gfax_home home
	global name atten phone prefix key

	# get the length of the original string and cut off white space
	set n [string trim $name]
	set l [string length $n]
	if {$l > 20} {
		userError Name
		return
	}

	# Now if the string is less than required, pad it with spaces
	if {$l < 20} {
		while {$l != 20} {
			append n " "
			incr l
		}
	}
	set a [string trim $atten]
	set l [string length $a]
	if {$l > 20} {
		userError Attention
		return
	}

	if {$l < 20} {
		while {$l != 20} {
			append a " "
			incr l
		}
	}
	set ph [string trim $phone]
	set l [string length $ph]
	if {$l > 15} {
		userError Phone
		return
	}

	if {$l < 15} {
		while {$l != 15} {
			append ph " "
			incr l
		}
	}
	set pr [string trim $prefix]
	set l [string length $pr]
	if {$l > 5} {
		userError Prefix
		return
	}

	if {$l < 1} {
		set pr None
	} elseif {$l < 5} {
		while {$l != 5} {
			append pr " "
			incr l
		}
	}


	# Set original vars for display.
	set name $n
	set atten $a
	set phone $ph
	set prefix $pr

	# This is the new edited entry
	set adbook_el $name:$atten:$phone:$prefix

	# Read the phone book and loop doing command

	# If a HOME/.gfax/phbook file exists use it
	if { [file readable $home/.gfax/phbook] } {
		set fd [open $home/.gfax/phbook r+]
	} else {
		set fd [open $gfax_home/phbook r+]
	}

	while {![eof $fd]} {
		gets $fd line

		if {$command == "Edit"} {
			set vars [split $line :]

			# If this is the changed entry don't append the old one.
			set s1 [lindex $vars 2]
			if {$s1 == $key} {
				continue
			}
		}

		lappend adbook $line
	}

	# Now add the changed entry.
	lappend adbook $adbook_el
	
	# Lets sort it
	set sortedbook [lsort $adbook]
	
	# Point to the beginning of the file.
	seek $fd 0
	
	# Now write the new file.
	foreach i $sortedbook { 
		# This will omit any null entries
		if {$i > 1} {
			puts $fd $i
		}
	}
	
	close $fd
	destroy .op
	
	# Reload the listbox
	LoadFile
}

# Go here if the entry has to many characters
proc userError {which} {

	toplevel .operror
	wm title .operror "User Error" 

	label .operror.label -text "\n$which entry to long!!\n" -padx 30
	pack .operror.label -side top
	
	button .operror.button -text Ok -padx 10 -command {destroy .operror}
	pack .operror.button -side top
}
