# sfax.tcl  -  96/07/19
##############################################################################
# GFax version 1.0
#
#   Copyright (c) 1996  George A. Farris,
#                       G.M. Systems,
#                       2570 Seaview Road,
#                       Mill Bay, British Columbia,
#                       Canada  V0R 2P0
#
#                       E-Mail: george@gmsys.com
#
#   All rights reserved.
#
#  Redistribution and use for non-commercial purposes in source and 
#  binary forms are permitted provided that the above copyright 
#  notice and this document are duplicated in all such forms and that 
#  any documentation, advertising materials, and other materials 
#  related to such distribution and use acknowledge that the software 
#  was developed by George A. Farris. 
#
#  This is SHAREWARE. As you will see from the following paragraphs,
#  I am trying to keep this as simple as possible while still
#  trying to get some benefit for myself from this software. 
#  It is an awful lot of work writing and maintaining such a package,
#  so please take the time to read this and comply to it.
#
#  Private use of GFax:
#
#  You are granted the right to use GFax for private purpose free
#  of charge.
#  
#  Using GFax in a commercial environment:        (very cheap!)
#  
#  A license for using GFax in a commercial or educational environment
#  can be obtained from the author for a small fee. To register your
#  copy of GFax, contact the author at the address above or just 
#  send an email. Registration fees for a "small" environment start
#  from US $10 and are negotiable. This will enable you to receive
#  full support and information on GFax development from the author.    
#
#  Distributions:
#
#  I would like to make GFax accessible to as many people as possible.
#  Therefor I grant the permission to include GFax in any Linux
#  distributions, as long as it is only a minor part of the distribution.
#  I would appreciate a copy of the distribution be sent to me for
#  support purposes but it isn't necessary.  You are not allowed to sell
#  or distribute any software package which is based mainly or derived from
#  GFax withour prior written permission from the author.
#  
#  If you are in doubt whether you can distribute GFax or not, just
#  contact the author. Including it in a distribution which is also
#  available free of charge (e.g. by FTP), is fine. 
#
#
#  NO WARRANTY:
#  
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
#  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-
#  INFRINGEMENT.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
#  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
#  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECT-
#  ION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
##############################################################################
proc sfax {} {
	global name atten phone prefix resolution user_name 
	global cover_page covpage_file send_now send_mail fax_number
	global network_fax fax_host net_port user_email gfax_home spool_dir
	global hour minute ampm day month year command RandName

	# If this is a network fax setup, open a connection to the fax
	# server on the (fax_host) and send the info and the file
	if { $network_fax } {
		donetfax
		exit
	}
	# End of network_fax
		
	# Ok it's a local fax setup.  We'll use faxspool under the megtty+sendfax
	# software with the expectation that mgetty+sendfax	is already setup to
	# send faxes and poll the queue files.

	# Set the initial command
	set command "faxspool -q"
	
	# Does resolution change?
	if {$resolution == 0} { set command "$command -n"}
	
	# Do we send email back to the user?
	if {$send_mail == 1} { set command "$command -f $user_email"}	
	
	# Do cover page stuff
	if {$cover_page} { 
		SfaxCovpg
	} else {
		set command "$command -C -"
	}
	
	# Send fax either now or at HH:MM
	if {!$send_now} {
		set hour24 $hour
		if {$ampm == "PM"} {set hour24 [expr $hour+12]}
		set command "$command -t $hour24:$minute"
	}
	
	# Add phone number
	#lets get ride of any spaces first
	set tprefix [string trim $prefix]
	set tphone [string trim $phone]
	
	if { $tprefix == "None"} {set command "$command \"$tphone\""}\
	 else {set command "$command \"$tprefix-$tphone\""}

	# Ok lets do it, spool the fax
	set spd ""
	
	# If sending just a cover page gfaxjob file is null.
	if { [file exists $spool_dir/D.$RandName] } {
		set spd $spool_dir/D.$RandName	
	}

	if [catch {eval exec "$command $spd"} result] {
		# Avoid error when printing from Wordperfect, maybe others

		set s_result [string trim $result]
		
		if { $s_result != "logname: no login name"} {
			if { ![string match "Printing*" $s_result] } {
				popmsg w "Alert" $result
				tkwait window .w
			}	
		}
		
	}
	if { [file exists $spool_dir/D.$RandName] } {
		exec rm $spool_dir/D.$RandName
	}
	if { [file exists $spool_dir/M.$RandName] } {
		exec rm $spool_dir/M.$RandName
	}

	exit
	
}

